Module: Kitchen::Terraform::ConfigAttribute::BackendConfigurations Abstract

Extended by:
Kitchen::Terraform::ConfigAttributeCacher
Included in:
Driver::Terraform
Defined in:
lib/kitchen/terraform/config_attribute/backend_configurations.rb

Overview

This module is abstract.

It must be included by a plugin class in order to be used.

The :backend_configurations configuration attribute is an optional hash of symobls and strings comprising Terraform backend configuration arguments to complete a partial backend.

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Kitchen::Terraform::ConfigAttributeCacher

define_cache, extended

Class Method Details

.included(plugin_class) ⇒ void

This method returns an undefined value.

A callback to define the configuration attribute which is invoked when this module is included in a plugin class.

Parameters:

  • plugin_class (::Kitchen::Configurable)

    A plugin class.



33
34
35
36
37
38
39
40
# File 'lib/kitchen/terraform/config_attribute/backend_configurations.rb', line 33

def self.included(plugin_class)
  ::Kitchen::Terraform::ConfigAttributeDefiner
    .new(
      attribute: self,
      schema: ::Kitchen::Terraform::ConfigSchemas::HashOfSymbolsAndStrings
    )
    .define plugin_class: plugin_class
end

.to_sym::Symbol

Returns the symbol corresponding to the attribute.

Returns:

  • (::Symbol)

    the symbol corresponding to the attribute.



43
44
45
# File 'lib/kitchen/terraform/config_attribute/backend_configurations.rb', line 43

def self.to_sym
  :backend_configurations
end

Instance Method Details

#config_backend_configurations_default_value::Hash

Returns an empty hash.

Returns:

  • (::Hash)

    an empty hash.



50
51
52
# File 'lib/kitchen/terraform/config_attribute/backend_configurations.rb', line 50

def config_backend_configurations_default_value
  {}
end