Module: Kitchen::Terraform::ConfigAttribute::Color
- Included in:
- Driver::Terraform, Verifier::Terraform
- Defined in:
- lib/kitchen/terraform/config_attribute/color.rb
Overview
This attribute toggles colored output from systems invoked by the plugin.
- Type
- Required
False
- Default
If a terminal emulator is associated with the Test Kitchen process then
true; elsefalse.- Example
color: false- Caveat
This attribute does not toggle colored output from the Test Kitchen core, though it does use the same default logic. To toggle colored output from the core, the
--colorand--no-colorcommand-line flags must be used.