Module: Kitchen::Terraform::ConfigAttribute::CommandTimeout Abstract

Extended by:
Kitchen::Terraform::ConfigAttributeCacher
Included in:
Driver::Terraform
Defined in:
lib/kitchen/terraform/config_attribute/command_timeout.rb

Overview

This module is abstract.

It must be included by a plugin class in order to be used.

The :command_timeout configuration attribute is an optional integer which represents the number of seconds to wait for the Terraform Client commands to finish.

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Kitchen::Terraform::ConfigAttributeCacher

define_cache, extended

Class Method Details

.included(plugin_class) ⇒ void

This method returns an undefined value.

A callback to define the configuration attribute which is invoked when this module is included in a plugin class.

Parameters:

  • plugin_class (::Kitchen::Configurable)

    A plugin class.



32
33
34
35
36
37
38
39
# File 'lib/kitchen/terraform/config_attribute/command_timeout.rb', line 32

def self.included(plugin_class)
  ::Kitchen::Terraform::ConfigAttributeDefiner
    .new(
      attribute: self,
      schema: ::Kitchen::Terraform::ConfigSchemas::Integer
    )
    .define plugin_class: plugin_class
end

.to_sym::Symbol

Returns the symbol corresponding to the attribute.

Returns:

  • (::Symbol)

    the symbol corresponding to the attribute.



42
43
44
# File 'lib/kitchen/terraform/config_attribute/command_timeout.rb', line 42

def self.to_sym
  :command_timeout
end

Instance Method Details

#config_command_timeout_default_value::Integer

Returns 600 seconds.

Returns:

  • (::Integer)

    600 seconds.



49
50
51
# File 'lib/kitchen/terraform/config_attribute/command_timeout.rb', line 49

def config_command_timeout_default_value
  600
end