Module: Kitchen::Terraform::ConfigAttribute::FailFast
- Included in:
- Verifier::Terraform
- Defined in:
- lib/kitchen/terraform/config_attribute/fail_fast.rb
Overview
This attribute toggles fail fast behaviour when verifying systems.
If fail fast behaviour is enabled then Kitchen will halt on the first error raised by a system during verification; else errors raised by systems will be queued until all systems have attempted verification.
- Type
- Required
False
- Default
true- Example
fail_fast: false