Module: Kitchen::Terraform::ConfigAttribute::VariableFiles Abstract

Extended by:
Kitchen::Terraform::ConfigAttributeCacher
Included in:
Driver::Terraform
Defined in:
lib/kitchen/terraform/config_attribute/variable_files.rb

Overview

This module is abstract.

It must be included by a plugin class in order to be used.

The :variable_files configuration attribute is an optional array of string which represent file paths.

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Kitchen::Terraform::ConfigAttributeCacher

define_cache, extended

Class Method Details

.included(plugin_class) ⇒ void

This method returns an undefined value.

A callback to define the configuration attribute which is invoked when this module is included in a plugin class.

Parameters:

  • plugin_class (::Kitchen::Configurable)

    A plugin class.



31
32
33
34
35
36
37
38
# File 'lib/kitchen/terraform/config_attribute/variable_files.rb', line 31

def self.included(plugin_class)
  ::Kitchen::Terraform::FilePathConfigAttributeDefiner
    .new(
      attribute: self,
      schema: ::Kitchen::Terraform::ConfigSchemas::ArrayOfStrings
    )
    .define plugin_class: plugin_class
end

.to_sym::Symbol

Returns the symbol corresponding to this attribute.

Returns:

  • (::Symbol)

    the symbol corresponding to this attribute.



41
42
43
# File 'lib/kitchen/terraform/config_attribute/variable_files.rb', line 41

def self.to_sym
  :variable_files
end

Instance Method Details

#config_variable_files_default_value::Array

Returns an empty array.

Returns:

  • (::Array)

    an empty array.



48
49
50
# File 'lib/kitchen/terraform/config_attribute/variable_files.rb', line 48

def config_variable_files_default_value
  []
end