Class: Kitchen::Terraform::FilePathConfigAttributeDefiner
- Inherits:
-
Object
- Object
- Kitchen::Terraform::FilePathConfigAttributeDefiner
- Defined in:
- lib/kitchen/terraform/file_path_config_attribute_definer.rb
Overview
Defines a file path configuration attribute on a plugin class.
Instance Method Summary collapse
-
#define(plugin_class:) ⇒ void
Defines the file path configuration attribute on a plugin class.
Instance Method Details
#define(plugin_class:) ⇒ void
This method returns an undefined value.
Defines the file path configuration attribute on a plugin class.
27 28 29 30 |
# File 'lib/kitchen/terraform/file_path_config_attribute_definer.rb', line 27 def define(plugin_class:) @definer.define plugin_class: plugin_class plugin_class. @attribute.to_sym end |