Module: Kitchen::Verifier::Terraform::ConfigureInspecRunnerBackend

Defined in:
lib/kitchen/verifier/terraform/configure_inspec_runner_backend.rb

Overview

Configures the backend for the Inspec::Runner used by the verifier to verify a group’s host.

If the hostname is “localhost” then the existing backend is overwritten to be “local”.

See Also:

Class Method Summary collapse

Class Method Details

.call(hostname:, options:) ⇒ Object

Invokes the function.

Parameters:

  • hostname (::String)

    the hostname being verified.

  • options (::Hash)

    the verifier’s Inspec::Runner options.



29
30
31
# File 'lib/kitchen/verifier/terraform/configure_inspec_runner_backend.rb', line 29

def self.call(hostname:, options:)
  hostname == "localhost" and options.store "backend", "local"
end