Module: Kitchen::Verifier::Terraform::ConfigureInspecRunnerBackend
- Defined in:
- lib/kitchen/verifier/terraform/configure_inspec_runner_backend.rb
Overview
Configures the backend for the Inspec::Runner used by the verifier to verify a group’s host.
If the hostname is “localhost” then the existing backend is overwritten to be “local”.
Class Method Summary collapse
-
.call(hostname:, options:) ⇒ Object
Invokes the function.
Class Method Details
.call(hostname:, options:) ⇒ Object
Invokes the function.
29 30 31 |
# File 'lib/kitchen/verifier/terraform/configure_inspec_runner_backend.rb', line 29 def self.call(hostname:, options:) hostname == "localhost" and .store "backend", "local" end |